@@ -1,4 +1,4 @@
-# $Id: //depot/ldap/lib/Net/LDAP/Control.pm#9 $
+# $Id: //depot/ldap/lib/Net/LDAP/Control.pm#10 $
 # Copyright (c) 1999-2000 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -176,7 +176,7 @@ L<Net::LDAP|Net::LDAP>
 Graham Barr <gbarr@pobox.com>
 
 Please report any bugs, or post any suggestions, to the perl-ldap mailing list
-<perl-ldap@mail.med.cornell.edu>
+<perl-ldap-dev@lists.sourceforge.net>
 
 =head1 COPYRIGHT
 
@@ -186,6 +186,6 @@ terms as Perl itself.
 
 =for html <hr>
 
-I<$Id: //depot/ldap/lib/Net/LDAP/Control.pm#9 $>
+I<$Id: //depot/ldap/lib/Net/LDAP/Control.pm#10 $>
 
 =cut
